@@ -5,13 +5,13 @@ import tarfile
 import xmlrpc
 import yaml
 import xml.etree.ElementTree as ET
-from celery import chord as celery_chord
+#from celery import chord as celery_chord
 from io import BytesIO
 from django.conf import settings
 from django.db import transaction
 from squad.plugins import Plugin as BasePlugin
 from urllib.parse import urljoin
-from squad.celery import app as celery
+#from squad.celery import app as celery
 from squad.core.utils import join_name
 from squad.core.models import Suite, SuiteMetadata, Test, KnownIssue, Status, TestRun, ProjectStatus
 from squad.core.tasks import get_suite
@@ -20,13 +20,13 @@ from squad.core.tasks import get_suite
 logger = logging.getLogger()
 
 
-@celery.task
+#@celery.task
 def update_build_status(results_list, testrun_id):
     testrun = TestRun.objects.get(pk=testrun_id)
     ProjectStatus.create_or_update(testrun.build)
 
 
-@celery.task
+#@celery.task
 def create_testcase_tests(test_case_string, module_name, testrun_id, suite_id):
     test_case = ET.fromstring(test_case_string)
     testrun = TestRun.objects.get(pk=testrun_id)
@@ -208,7 +208,7 @@ class Tradefed(BasePlugin):
         logger.debug("Tests: {}".format(len(test_elems)))
         elems = tradefed_tree.findall('Module')
         logger.debug("Modules: {}".format(len(elems)))
-        task_list = []
+        #task_list = []
         for elem in elems:
             # Naming: Module Name + Test Case Name + Test Name
             if 'abi' in elem.attrib.keys():
@@ -224,11 +224,13 @@ class Tradefed(BasePlugin):
             logger.debug("creating suite metadata: {}".format(atomic_test_suite_name))
             suite_metadata, _ = SuiteMetadata.objects.get_or_create(suite=atomic_test_suite_name, kind='suite')
             suite, _ = Suite.objects.get_or_create(slug=atomic_test_suite_name, project=testrun.build.project, defaults={"metadata": suite_metadata})
-            logger.debug("Adding status with suite: {suite_prefix}/{module_name}".format(suite_prefix=suite_prefix, module_name=module_name))
-            logger.debug("Creating subtasks for extracting results")
-            task_list = task_list + [create_testcase_tests.s(ET.tostring(test_case, encoding="utf-8"), module_name, testrun.pk, suite.pk) for test_case in test_cases]
+            #logger.debug("Adding status with suite: {suite_prefix}/{module_name}".format(suite_prefix=suite_prefix, module_name=module_name))
+            #logger.debug("Creating subtasks for extracting results")
+            #task_list = task_list + [create_testcase_tests.s(ET.tostring(test_case, encoding="utf-8"), module_name, testrun.pk, suite.pk) for test_case in test_cases]
+            for test_case in test_cases:
+                create_testcase_tests(ET.tostring(test_case, encoding="utf-8"), module_name, testrun.pk, suite.pk)
 
-        celery_chord(task_list)(update_build_status.s(testrun.pk))
+        #celery_chord(task_list)(update_build_status.s(testrun.pk))
 
     def _assign_test_log(self, buf, test_list):
         # assume buf is a file-like object
